# Open Music Kit
> Tools for computational music analysis.


Do you *really* think that G$\flat$ and F$\sharp$ are the same note?

## Install

`pip install openmusickit`

## How to use

`import openmusickit as omk`
